==> qtjambi-sensors-6.5.3-sources.jar: io/qt/sensors/QMagnetometerReading.java <==
package io.qt.sensors;

import io.qt.*;


/**
 * <p>Represents one reading from the magnetometer</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qmagnetometerreading.html">QMagnetometerReading</a></code></p>
 */
public class QMagnetometerReading extends io.qt.sensors.QSensorReading
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QMagnetometerReading.class);
    
    
    /**
     * <p>See <code>QMagnetometerReading::<wbr>QMagnetometerReading(QObject*)</code></p>
     */
    public QMagnetometerReading(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QMagnetometerReading instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qmagnetometerreading.html#calibrationLevel-prop">QMagnetometerReading::<wbr>calibrationLevel()const</a></code></p>
     */
    @QtPropertyReader(name="calibrationLevel")
    @QtUninvokable
    public final double calibrationLevel(){
        return calibrationLevel_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native double calibrationLevel_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qmagnetometerreading.html#setCalibrationLevel">QMagnetometerReading::<wbr>setCalibrationLevel(qreal)</a></code></p>
     */
    @QtUninvokable
    public final void setCalibrationLevel(double calibrationLevel){
        setCalibrationLevel_native_qreal(QtJambi_LibraryUtilities.internal.nativeId(this), calibrationLevel);
    }
    
    @QtUninvokable
    private native void setCalibrationLevel_native_qreal(long __this__nativeId, double calibrationLevel);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qmagnetometerreading.html#setX">QMagnetometerReading::<wbr>setX(qreal)</a></code></p>
     */
    @QtUninvokable
    public final void setX(double x){
        setX_native_qreal(QtJambi_LibraryUtilities.internal.nativeId(this), x);
    }
    
    @QtUninvokable
    private native void setX_native_qreal(long __this__nativeId, double x);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qmagnetometerreading.html#setY">QMagnetometerReading::<wbr>setY(qreal)</a></code></p>
     */
    @QtUninvokable
    public final void setY(double y){
        setY_native_qreal(QtJambi_LibraryUtilities.internal.nativeId(this), y);
    }
    
    @QtUninvokable
    private native void setY_native_qreal(long __this__nativeId, double y);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qmagnetometerreading.html#setZ">QMagnetometerReading::<wbr>setZ(qreal)</a></code></p>
     */
    @QtUninvokable
    public final void setZ(double z){
        setZ_native_qreal(QtJambi_LibraryUtilities.internal.nativeId(this), z);
    }
    
    @QtUninvokable
    private native void setZ_native_qreal(long __this__nativeId, double z);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qmagnetometerreading.html#x-prop">QMagnetometerReading::<wbr>x()const</a></code></p>
     */
    @QtPropertyReader(name="x")
    @QtUninvokable
    public final double x(){
        return x_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native double x_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qmagnetometerreading.html#y-prop">QMagnetometerReading::<wbr>y()const</a></code></p>
     */
    @QtPropertyReader(name="y")
    @QtUninvokable
    public final double y(){
        return y_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native double y_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qmagnetometerreading.html#z-prop">QMagnetometerReading::<wbr>z()const</a></code></p>
     */
    @QtPropertyReader(name="z")
    @QtUninvokable
    public final double z(){
        return z_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native double z_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QSensorReading::<wbr>copyValuesFrom(QSensorReading*)</code></p>
     */
    @QtUninvokable
    @Override
    protected void copyValuesFrom(io.qt.sensors.@Nullable QSensorReading other){
        copyValuesFrom_native_QSensorReading_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native void copyValuesFrom_native_QSensorReading_ptr(long __this__nativeId, long other);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QMagnetometerReading(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QMagnetometerReading(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QMagnetometerReading instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QMagnetometerReading(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QMagnetometerReading() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>Kotlin property getter. In Java use {@link #calibrationLevel()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final double getCalibrationLevel() {
        return calibrationLevel();
    }
    
    /**
     * <p>Kotlin property getter. In Java use {@link #x()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final double getX() {
        return x();
    }
    
    /**
     * <p>Kotlin property getter. In Java use {@link #y()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final double getY() {
        return y();
    }
    
    /**
     * <p>Kotlin property getter. In Java use {@link #z()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final double getZ() {
        return z();
    }
}

==> qtjambi-sensors-6.6.2-sources.jar: io/qt/sensors/QMagnetometerReading.java <==
package io.qt.sensors;

import io.qt.*;


/**
 * <p>Represents one reading from the magnetometer</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qmagnetometerreading.html">QMagnetometerReading</a></code></p>
 */
public class QMagnetometerReading extends io.qt.sensors.QSensorReading
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QMagnetometerReading.class);
    
    
    /**
     * <p>See <code>QMagnetometerReading::<wbr/>QMagnetometerReading(QObject*)</code></p>
     */
    public QMagnetometerReading(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QMagnetometerReading instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qmagnetometerreading.html#calibrationLevel-prop">QMagnetometerReading::<wbr/>calibrationLevel()const</a></code></p>
     */
    @QtPropertyReader(name="calibrationLevel")
    @QtUninvokable
    public final double calibrationLevel(){
        return calibrationLevel_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native double calibrationLevel_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qmagnetometerreading.html#setCalibrationLevel">QMagnetometerReading::<wbr/>setCalibrationLevel(qreal)</a></code></p>
     */
    @QtUninvokable
    public final void setCalibrationLevel(double calibrationLevel){
        setCalibrationLevel_native_qreal(QtJambi_LibraryUtilities.internal.nativeId(this), calibrationLevel);
    }
    
    @QtUninvokable
    private native void setCalibrationLevel_native_qreal(long __this__nativeId, double calibrationLevel);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qmagnetometerreading.html#setX">QMagnetometerReading::<wbr/>setX(qreal)</a></code></p>
     */
    @QtUninvokable
    public final void setX(double x){
        setX_native_qreal(QtJambi_LibraryUtilities.internal.nativeId(this), x);
    }
    
    @QtUninvokable
    private native void setX_native_qreal(long __this__nativeId, double x);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qmagnetometerreading.html#setY">QMagnetometerReading::<wbr/>setY(qreal)</a></code></p>
     */
    @QtUninvokable
    public final void setY(double y){
        setY_native_qreal(QtJambi_LibraryUtilities.internal.nativeId(this), y);
    }
    
    @QtUninvokable
    private native void setY_native_qreal(long __this__nativeId, double y);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qmagnetometerreading.html#setZ">QMagnetometerReading::<wbr/>setZ(qreal)</a></code></p>
     */
    @QtUninvokable
    public final void setZ(double z){
        setZ_native_qreal(QtJambi_LibraryUtilities.internal.nativeId(this), z);
    }
    
    @QtUninvokable
    private native void setZ_native_qreal(long __this__nativeId, double z);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qmagnetometerreading.html#x-prop">QMagnetometerReading::<wbr/>x()const</a></code></p>
     */
    @QtPropertyReader(name="x")
    @QtUninvokable
    public final double x(){
        return x_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native double x_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qmagnetometerreading.html#y-prop">QMagnetometerReading::<wbr/>y()const</a></code></p>
     */
    @QtPropertyReader(name="y")
    @QtUninvokable
    public final double y(){
        return y_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native double y_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qmagnetometerreading.html#z-prop">QMagnetometerReading::<wbr/>z()const</a></code></p>
     */
    @QtPropertyReader(name="z")
    @QtUninvokable
    public final double z(){
        return z_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native double z_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QSensorReading::<wbr/>copyValuesFrom(QSensorReading*)</code></p>
     */
    @QtUninvokable
    @Override
    protected void copyValuesFrom(io.qt.sensors.@Nullable QSensorReading other){
        copyValuesFrom_native_QSensorReading_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native void copyValuesFrom_native_QSensorReading_ptr(long __this__nativeId, long other);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QMagnetometerReading(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     * @hidden
     */
    @NativeAccess
    protected QMagnetometerReading(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QMagnetometerReading instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QMagnetometerReading(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QMagnetometerReading() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #calibrationLevel()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final double getCalibrationLevel() {
        return calibrationLevel();
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #x()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final double getX() {
        return x();
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #y()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final double getY() {
        return y();
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #z()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final double getZ() {
        return z();
    }
}
